@@ -7,8 +7,8 @@ from the author. You can redistribute it and/or modify it under the terms of
 the GNU General Public License as published by the Free Software Foundation.
 Either version 2 of the License, or (at your option) any later version.
 
-http://www.isis.de/members/~s.frings
-mailto:stefan.frings@vodafone.de
+http://www.meinemullemaus.de/
+mailto: smstools@meinemullemaus.de
 */
 
 #include <syslog.h>
@@ -33,11 +33,16 @@ int inblacklist(char* msisdn)
         if (posi)
           *posi=0;
         cutspaces(line);
-        if (strcmp(msisdn,line)==0)
+        if (strncmp(msisdn,line,strlen(line))==0)
 	{
 	  fclose(file);
           return 1;
 	}  
+        else if (msisdn[0]=='s' && strncmp(msisdn+1,line,strlen(line))==0)
+        {
+          fclose(file);
+          return 1;
+        }
       }  
       fclose(file);
     }  
