@@ -7,8 +7,8 @@ from the author. You can redistribute it and/or modify it under the terms of
 the GNU General Public License as published by the Free Software Foundation.
 Either version 2 of the License, or (at your option) any later version.
 
-http://www.isis.de/members/~s.frings
-mailto:stefan.frings@vodafone.de
+http://www.meinemullemaus.de/
+mailto: smstools@meinemullemaus.de
 */
 
 #include <stdio.h>
