@@ -7,8 +7,8 @@ from the author. You can redistribute it and/or modify it under the terms of
 the GNU General Public License as published by the Free Software Foundation.
 Either version 2 of the License, or (at your option) any later version.
 
-http://www.isis.de/members/~s.frings
-mailto:stefan.frings@vodafone.de
+http://www.meinemullemaus.de/
+mailto: smstools@meinemullemaus.de
 */
 
 #include <sys/types.h>
@@ -589,7 +589,7 @@ void parsearguments(int argc,char** argv)
                 break;
       case 'o': strcpy(outputfile, optarg);
                 break;
-      case 'V': printf("Version %s, Copyright (c) Stefan Frings, stefan.frings@vodafone.de\n",getsms_version);
+      case 'V': printf("Version %s, Copyright (c) Stefan Frings, smstools@meinemullemaus.de\n",getsms_version);
                 exit(0);
     }
   }
