@@ -7,8 +7,8 @@ from the author. You can redistribute it and/or modify it under the terms of
 the GNU General Public License as published by the Free Software Foundation.
 Either version 2 of the License, or (at your option) any later version.
 
-http://www.isis.de/members/~s.frings
-mailto:stefan.frings@vodafone.de
+http://www.meinemullemaus.de/
+mailto: smstools@meinemullemaus.de
 */
 
 #include <errno.h>
@@ -376,13 +376,13 @@ void mainspooler()
 	{
 	  if (black)
 	  {
-	    writelogfile(LOG_NOTICE,"Invalid To: field in message file %s (blacklist).",filename);
-	    alarm_handler(LOG_NOTICE,"SMSD","Invalid To: field in message file %s (blacklist).",filename);
+	    writelogfile(LOG_NOTICE,"Invalid To: field in message file %s (blacklisted).",filename);
+	    alarm_handler(LOG_NOTICE,"SMSD","Invalid To: field in message file %s (blacklisted).",filename);
 	  }
 	  else if (whitelist[0] && white==0)
 	  {
-	    writelogfile(LOG_NOTICE,"Invalid To: field in message file %s (whitelist).",filename);
-	    alarm_handler(LOG_NOTICE,"SMSD","Invalid To: field in message file %s (whitelist).",filename); 
+	    writelogfile(LOG_NOTICE,"Invalid To: field in message file %s (not in whitelist).",filename);
+	    alarm_handler(LOG_NOTICE,"SMSD","Invalid To: field in message file %s (not in whitelist).",filename); 
 	  }
 	  else if (checked!=0)
 	  {
